@@ -5,15 +5,11 @@ use 5.008001;
 use strict;
 use warnings;
 
-# OK, the following is probably paranoia. But if Perl 7 decides to
-# change this particular default I'm ready. Unless they eliminate $].
-no if $] ge '5.020', feature => qw{ signatures };
-
 use Carp;
 use Exporter qw{ import };
 use File::Spec;
 
-our $VERSION = '0.004_01';
+our $VERSION = '0.001';
 
 our @EXPORT_OK = qw{
     symlink_r
@@ -45,6 +41,7 @@ sub symlink_r ($$) {	## no critic (ProhibitSubroutinePrototypes)
     return symlink $relative, $target;
 }
 
+
 1;
 
 __END__
@@ -111,9 +108,7 @@ L<https://www.reddit.com/r/perl/comments/fluxay/can_i_make_relative_symbolic_lin
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Symlink-Relative>,
-L<https://github.com/trwyant/perl-File-Symlink-Relative/issues>, or in
-electronic mail to the author.
+L<https://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -121,7 +116,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2020-2021 by Thomas R. Wyant, III
+Copyright (C) 2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
